# StartPeriodsType

Unit of time that the discount charge duration is measured in. Only applicable if the value of the `startDatePolicy` field is `FixedPeriodAfterApplyToChargeStartDate`. 

## Enum

* `DAYS` (value: `'Days'`)

* `WEEKS` (value: `'Weeks'`)

* `MONTHS` (value: `'Months'`)

* `YEARS` (value: `'Years'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


